@@ -22,7 +22,7 @@ build_time_vars = {'ABIFLAGS': '',
  'BYTESTR_DEPS': '\\',
  'CC': 'x86_64-pc-linux-gnu-gcc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG',
+ 'CFLAGS': '-Wno-unused-result -Wsign-compare',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
@@ -61,7 +61,7 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--without-ensurepip' '--without-lto' '--with-system-expat' "
                 "'--with-system-ffi' '--with-system-libmpdec' "
                 "'--with-wheel-pkg-dir=/usr/lib/python/ensurepip' "
-                "'--without-assertions' '--enable-optimizations' "
+                "'--with-assertions' '--enable-optimizations' "
                 "'--with-readline=readline' '--without-valgrind' '--with-lto' "
                 "'build_alias=x86_64-pc-linux-gnu' "
                 "'host_alias=x86_64-pc-linux-gnu' 'CFLAGS=' 'LDFLAGS=' "
@@ -557,15 +557,14 @@ build_time_vars = {'ABIFLAGS': '',
                    '/usr/include/python3.10',
  'INCLUDEDIR': '/usr/include',
  'INCLUDEPY': '/usr/include/python3.10',
- 'INSTALL': '/var/tmp/portage/._portage_reinstall_.818jrldh/bin/ebuild-helpers/xattr/install '
-            '-c',
- 'INSTALL_DATA': '/var/tmp/portage/._portage_reinstall_.818jrldh/bin/ebuild-helpers/xattr/install '
-                 '-c -m 644',
- 'INSTALL_PROGRAM': '/var/tmp/portage/._portage_reinstall_.818jrldh/bin/ebuild-helpers/xattr/install '
+ 'INSTALL': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install -c',
+ 'INSTALL_DATA': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install -c '
+                 '-m 644',
+ 'INSTALL_PROGRAM': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
                     '-c',
- 'INSTALL_SCRIPT': '/var/tmp/portage/._portage_reinstall_.818jrldh/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SCRIPT': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
                    '-c',
- 'INSTALL_SHARED': '/var/tmp/portage/._portage_reinstall_.818jrldh/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SHARED': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
                    '-c -m 755',
  'INSTSONAME': 'libpython3.10.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
@@ -639,7 +638,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPENSSL_RPATH': '',
- 'OPT': '-DNDEBUG',
+ 'OPT': '',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -677,8 +676,8 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-                             '-pipe -march=x86-64 -mtune=generic -Werror=odr '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -O2 -pipe '
+                             '-march=x86-64 -mtune=generic -Werror=odr '
                              '-Werror=lto-type-mismatch '
                              '-Werror=strict-aliasing -flto -ffat-lto-objects '
                              '-fno-semantic-interposition -flto '
@@ -692,7 +691,7 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fprofile-correction -I./Include/internal -I. '
                              '-I./Include -I/usr/include/ncursesw -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG',
+ 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare',
  'PY_CFLAGS_NODIST': '-O2 -pipe -march=x86-64 -mtune=generic -Werror=odr '
                      '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
                      '-ffat-lto-objects -fno-semantic-interposition -flto '
@@ -703,17 +702,16 @@ build_time_vars = {'ABIFLAGS': '',
                      '-fvisibility=hidden -fprofile-use -fprofile-correction '
                      '-I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -pipe '
-                   '-march=x86-64 -mtune=generic -Werror=odr '
-                   '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
-                   '-ffat-lto-objects -fno-semantic-interposition -flto '
-                   '-fuse-linker-plugin -ffat-lto-objects -g -std=c99 -Wextra '
-                   '-Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers -Wstrict-prototypes '
-                   '-Werror=implicit-function-declaration -fvisibility=hidden '
-                   '-fprofile-use -fprofile-correction -I./Include/internal '
-                   '-I. -I./Include -I/usr/include/ncursesw -fPIC '
-                   '-DPy_BUILD_CORE',
+ 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -O2 -pipe -march=x86-64 '
+                   '-mtune=generic -Werror=odr -Werror=lto-type-mismatch '
+                   '-Werror=strict-aliasing -flto -ffat-lto-objects '
+                   '-fno-semantic-interposition -flto -fuse-linker-plugin '
+                   '-ffat-lto-objects -g -std=c99 -Wextra -Wno-unused-result '
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-Wstrict-prototypes -Werror=implicit-function-declaration '
+                   '-fvisibility=hidden -fprofile-use -fprofile-correction '
+                   '-I./Include/internal -I. -I./Include '
+                   '-I/usr/include/ncursesw -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
                     '-Werror=odr -Werror=lto-type-mismatch '
                     '-Werror=strict-aliasing -flto -fno-semantic-interposition '
@@ -729,7 +727,7 @@ build_time_vars = {'ABIFLAGS': '',
                       '-ffat-lto-objects -g',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -pipe '
+ 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -O2 -pipe '
                         '-march=x86-64 -mtune=generic -Werror=odr '
                         '-Werror=lto-type-mismatch -Werror=strict-aliasing '
                         '-flto -ffat-lto-objects -fno-semantic-interposition '
